( cd opt/kde/share/doc/HTML/ru/ark ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/ark ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/ktuberling ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/ktuberling ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kmix ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kmix ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kodo ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kodo ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kolf ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kolf ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kppp ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kppp ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/krec ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/krec ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kscd ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kscd ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kbattleship ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kbattleship ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kfloppy ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kfloppy ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kandy ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kandy ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kwin4 ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kwin4 ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/lskat ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/lskat ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/ksnapshot ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/khelpcenter/faq ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/khelpcenter/faq ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/khelpcenter/quickstart ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/khelpcenter/quickstart ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/khelpcenter/glossary ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/khelpcenter/glossary ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/khelpcenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/khelpcenter/userguide ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/khelpcenter/userguide ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/khelpcenter/visualdict ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/khelpcenter/visualdict ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/ksirtet ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/ksirtet ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kspaceduel ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kwuftpd ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kwuftpd ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/aktion ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/aktion ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kxconfig ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kxconfig ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf fdl-license )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/fdl-license fdl-license )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf qpl-license.html )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/qpl-license.html qpl-license.html )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf x11-license.html )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/x11-license.html x11-license.html )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf 1.png )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/1.png 1.png )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf xml.dcl )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/xml.dcl xml.dcl )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf 2.png )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/2.png 2.png )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf 3.png )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/3.png 3.png )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf 4.png )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/4.png 4.png )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf 5.png )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/5.png 5.png )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf 6.png )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/6.png 6.png )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf 7.png )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/7.png 7.png )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf 8.png )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/8.png 8.png )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf 9.png )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/9.png 9.png )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf headerbg.png )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/headerbg.png headerbg.png )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf gpl-license.html )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/gpl-license.html gpl-license.html )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf mainheader.html )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/mainheader.html mainheader.html )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf grad.png )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/grad.png grad.png )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf kde-web.css )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf lgpl-license.html )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf doxygen.css )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/doxygen.css doxygen.css )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf web-doctop.png )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/web-doctop.png web-doctop.png )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf kde-default.css )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/kde-default.css kde-default.css )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf kmenu.png )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/kmenu.png kmenu.png )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf footer.html )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/footer.html footer.html )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf kde-common.css )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf doctop1.png )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf doctop2.png )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf shadow.png )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/shadow.png shadow.png )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf docheadergears.png )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf fdl-license.html )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf doctop1a.png )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf 10.png )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/10.png 10.png )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf doctop1b.png )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/doctop1b.png doctop1b.png )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf lgpl-license )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/lgpl-license lgpl-license )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf mainfooter.html )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/mainfooter.html mainfooter.html )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf bottom1.png )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/bottom1.png bottom1.png )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf bottom2.png )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf header.html )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/header.html header.html )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf gpl-license )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/gpl-license gpl-license )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf kde-localised.css.template )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/kde-localised.css.template kde-localised.css.template )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf bsd-license.html )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/bsd-license.html bsd-license.html )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf web-docbottom.png )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
( cd opt/kde/share/doc/HTML/ru/common ; rm -rf artistic-license.html )
( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
( cd opt/kde/share/doc/HTML/ru/kcontrol/arts ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kcontrol/arts ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kcontrol/clock ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kcontrol/clock ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kcontrol/mouse ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kcontrol/mouse ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kcontrol/kmixcfg ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kcontrol ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kcontrol ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kcontrol/kcmlaunch ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kcontrol/kcmlaunch ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kcontrol/useragent ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kcontrol/useragent ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kcontrol/keyboard ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kcontrol/keyboard ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/artsbuilder ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/artsbuilder ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kicker-applets ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/konq-plugins/crashes ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/konq-plugins/crashes ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/konq-plugins/babel ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/konq-plugins/babel ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kbabel ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kbabel ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kicker ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kicker ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/klines ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/klines ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kmines ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kmines ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kpager ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kpager ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/ktalkd ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/ktalkd ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kstars ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kstars ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/megami ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/megami ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/noatun ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/noatun ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kdebugdialog ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kpovmodeler ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kpovmodeler ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kenolaba ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kenolaba ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kgpgcertmanager ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kgpgcertmanager ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kworldclock ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kworldclock ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/KRegExpEditor ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/KRegExpEditor ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kinfocenter/pci ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kinfocenter/pci ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kinfocenter/xserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kinfocenter/xserver ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kinfocenter/sound ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kinfocenter/partitions ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kinfocenter/pcmcia ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kinfocenter/processor ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kate-plugins ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/konqueror ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/konqueror ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/atlantik ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/atlantik ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
